IKDeviceBrowserViewDelegate

Trait IKDeviceBrowserViewDelegate 

pub unsafe trait IKDeviceBrowserViewDelegate {
    // Provided methods
    unsafe fn deviceBrowserView_selectionDidChange(
        &self,
        device_browser_view: Option<&IKDeviceBrowserView>,
        device: Option<&ICDevice>,
    )
       where Self: Sized + Message { ... }
    unsafe fn deviceBrowserView_didEncounterError(
        &self,
        device_browser_view: Option<&IKDeviceBrowserView>,
        error: Option<&NSError>,
    )
       where Self: Sized + Message { ... }
}
Available on crate features IKDeviceBrowserView and ImageKit only.
A delegate of IKDeviceBrowserView must conform to IKDeviceBrowserViewDelegate protocol.

See also Apple’s documentation

Provided Methods

unsafe fn deviceBrowserView_selectionDidChange( &self, device_browser_view: Option<&IKDeviceBrowserView>, device: Option<&ICDevice>, )
where Self: Sized + Message,

Available on crate feature objc2-image-capture-core only.

This message is sent when the user selection did change.

The device may be a ICCameraDevice or a ICScannerDevice.

Safety
  • device_browser_view might not allow None.
  • device might not allow None.
unsafe fn deviceBrowserView_didEncounterError( &self, device_browser_view: Option<&IKDeviceBrowserView>, error: Option<&NSError>, )
where Self: Sized + Message,

This message is sent every time the device browser reports an error.

Safety
  • device_browser_view might not allow None.
  • error might not allow None.