IKFilterCustomUIProvider

Trait IKFilterCustomUIProvider 

pub unsafe trait IKFilterCustomUIProvider {
    // Provided method
    unsafe fn provideViewForUIConfiguration_excludedKeys(
        &self,
        in_ui_configuration: Option<&NSDictionary>,
        in_keys: Option<&NSArray>,
        mtm: MainThreadMarker,
    ) -> Option<Retained<IKFilterUIView>>
       where Self: Sized + Message { ... }
}
Available on crate features IKFilterUI and ImageKit only.
The IKFilterCustomUIProvider needs to be implemented by a filter to implement its own UI.

When a filter wants to provide its own UI for all or only some configurations, it has to implement the provideViewForUIConfiguration method.

See also Apple’s documentation

Provided Methods

unsafe fn provideViewForUIConfiguration_excludedKeys( &self, in_ui_configuration: Option<&NSDictionary>, in_keys: Option<&NSArray>, mtm: MainThreadMarker, ) -> Option<Retained<IKFilterUIView>>
where Self: Sized + Message,

Available on crate feature IKFilterUIView only.

The provideViewForUIConfiguration gets called, when a client requests a filter UI by calling viewForUIConfiguration:excludedKeys.

See description in viewForUIConfiguration:excludedKeys for details on the parameters. If a filter cannot provide a IKFilterUIView for a given UIConfiguration, it can return nil and the CoreImageKit framework will try to provide a UI for it instead.

Safety
  • in_ui_configuration generic should be of the correct type.
  • in_ui_configuration might not allow None.
  • in_keys generic should be of the correct type.
  • in_keys might not allow None.