IKImageEditPanelDataSource

Trait IKImageEditPanelDataSource 

pub unsafe trait IKImageEditPanelDataSource {
    // Provided methods
    unsafe fn image(&self) -> Option<Retained<CGImage>>
       where Self: Sized + Message { ... }
    unsafe fn setImage_imageProperties(
        &self,
        image: Option<&CGImage>,
        meta_data: Option<&NSDictionary>,
    )
       where Self: Sized + Message { ... }
    unsafe fn thumbnailWithMaximumSize(
        &self,
        size: NSSize,
    ) -> Option<Retained<CGImage>>
       where Self: Sized + Message { ... }
    unsafe fn imageProperties(&self) -> Retained<NSDictionary>
       where Self: Sized + Message { ... }
    unsafe fn hasAdjustMode(&self) -> bool
       where Self: Sized + Message { ... }
    unsafe fn hasEffectsMode(&self) -> bool
       where Self: Sized + Message { ... }
    unsafe fn hasDetailsMode(&self) -> bool
       where Self: Sized + Message { ... }
}
Available on crate features IKImageEditPanel and ImageKit only.
The data source of IKImageEditPanel must conform to IKImageEditPanelDataSource protocol.

See also Apple’s documentation

Provided Methods

unsafe fn image(&self) -> Option<Retained<CGImage>>
where Self: Sized + Message,

Available on crate feature objc2-core-graphics only.

Returns an image.

unsafe fn setImage_imageProperties( &self, image: Option<&CGImage>, meta_data: Option<&NSDictionary>, )
where Self: Sized + Message,

Available on crate feature objc2-core-graphics only.

Sets an image with the specifies properties.

Safety
  • image might not allow None.
  • meta_data generic should be of the correct type.
  • meta_data might not allow None.
unsafe fn thumbnailWithMaximumSize( &self, size: NSSize, ) -> Option<Retained<CGImage>>
where Self: Sized + Message,

Available on crate feature objc2-core-graphics only.

Returns a thumbnail image whose size is no larger than the specified size.

unsafe fn imageProperties(&self) -> Retained<NSDictionary>
where Self: Sized + Message,

Returns a dictionary of the image properties associated with the image in the image edit panel.

unsafe fn hasAdjustMode(&self) -> bool
where Self: Sized + Message,

Show the adjust view tab

unsafe fn hasEffectsMode(&self) -> bool
where Self: Sized + Message,

Show the effects view tab

unsafe fn hasDetailsMode(&self) -> bool
where Self: Sized + Message,

Show the details view tab