pub unsafe trait IKImageEditPanelDataSource {
// Provided methods
unsafe fn image(&self) -> Option<Retained<CGImage>>
where Self: Sized + Message { ... }
unsafe fn setImage_imageProperties(
&self,
image: Option<&CGImage>,
meta_data: Option<&NSDictionary>,
)
where Self: Sized + Message { ... }
unsafe fn thumbnailWithMaximumSize(
&self,
size: NSSize,
) -> Option<Retained<CGImage>>
where Self: Sized + Message { ... }
unsafe fn imageProperties(&self) -> Retained<NSDictionary>
where Self: Sized + Message { ... }
unsafe fn hasAdjustMode(&self) -> bool
where Self: Sized + Message { ... }
unsafe fn hasEffectsMode(&self) -> bool
where Self: Sized + Message { ... }
unsafe fn hasDetailsMode(&self) -> bool
where Self: Sized + Message { ... }
}Available on crate features
IKImageEditPanel and ImageKit only.Expand description
The data source of IKImageEditPanel must conform to IKImageEditPanelDataSource protocol.
See also Apple’s documentation
Provided Methods
Sourceunsafe fn image(&self) -> Option<Retained<CGImage>>
Available on crate feature objc2-core-graphics only.
unsafe fn image(&self) -> Option<Retained<CGImage>>
objc2-core-graphics only.Returns an image.
Sourceunsafe fn setImage_imageProperties(
&self,
image: Option<&CGImage>,
meta_data: Option<&NSDictionary>,
)
Available on crate feature objc2-core-graphics only.
unsafe fn setImage_imageProperties( &self, image: Option<&CGImage>, meta_data: Option<&NSDictionary>, )
objc2-core-graphics only.Sets an image with the specifies properties.
Safety
imagemight not allowNone.meta_datageneric should be of the correct type.meta_datamight not allowNone.
Sourceunsafe fn thumbnailWithMaximumSize(
&self,
size: NSSize,
) -> Option<Retained<CGImage>>
Available on crate feature objc2-core-graphics only.
unsafe fn thumbnailWithMaximumSize( &self, size: NSSize, ) -> Option<Retained<CGImage>>
objc2-core-graphics only.Returns a thumbnail image whose size is no larger than the specified size.
Sourceunsafe fn imageProperties(&self) -> Retained<NSDictionary>
unsafe fn imageProperties(&self) -> Retained<NSDictionary>
Returns a dictionary of the image properties associated with the image in the image edit panel.
Sourceunsafe fn hasAdjustMode(&self) -> bool
unsafe fn hasAdjustMode(&self) -> bool
Show the adjust view tab
Sourceunsafe fn hasEffectsMode(&self) -> bool
unsafe fn hasEffectsMode(&self) -> bool
Show the effects view tab
Sourceunsafe fn hasDetailsMode(&self) -> bool
unsafe fn hasDetailsMode(&self) -> bool
Show the details view tab